@@ -24,6 +24,11 @@ from calibre.utils.localization import get_lang
 from calibre.utils.filenames import expanduser
 from calibre.utils.file_type_icons import EXT_MAP
 
+try:
+    NO_URL_FORMATTING = QUrl.None_
+except AttributeError:
+    NO_URL_FORMATTING = QUrl.None
+
 # Setup gprefs {{{
 gprefs = JSONConfig('gui')
 defs = gprefs.defaults
@@ -678,15 +683,84 @@ class FileDialog(QObject):
             return tuple(os.path.abspath(unicode(i)) for i in self.fd.selectedFiles())
         return tuple(self.selected_files)
 
+has_windows_file_dialog_helper = False
+if iswindows and 'CALIBRE_NO_NATIVE_FILEDIALOGS' not in os.environ:
+    from calibre.gui2.win_file_dialogs import is_ok as has_windows_file_dialog_helper
+    has_windows_file_dialog_helper = has_windows_file_dialog_helper()
+if has_windows_file_dialog_helper:
+    from calibre.gui2.win_file_dialogs import choose_files, choose_images, choose_dir, choose_save_file
+else:
 
-def choose_dir(window, name, title, default_dir='~', no_save_dir=False):
-    fd = FileDialog(title=title, filters=[], add_all_files_filter=False,
-            parent=window, name=name, mode=QFileDialog.Directory,
-            default_dir=default_dir, no_save_dir=no_save_dir)
-    dir = fd.get_files()
-    fd.setParent(None)
-    if dir:
-        return dir[0]
+    def choose_dir(window, name, title, default_dir='~', no_save_dir=False):
+        fd = FileDialog(title=title, filters=[], add_all_files_filter=False,
+                parent=window, name=name, mode=QFileDialog.Directory,
+                default_dir=default_dir, no_save_dir=no_save_dir)
+        dir = fd.get_files()
+        fd.setParent(None)
+        if dir:
+            return dir[0]
+
+    def choose_files(window, name, title,
+                    filters=[], all_files=True, select_only_single_file=False, default_dir=u'~'):
+        '''
+        Ask user to choose a bunch of files.
+        :param name: Unique dialog name used to store the opened directory
+        :param title: Title to show in dialogs titlebar
+        :param filters: list of allowable extensions. Each element of the list
+                        must be a 2-tuple with first element a string describing
+                        the type of files to be filtered and second element a list
+                        of extensions.
+        :param all_files: If True add All files to filters.
+        :param select_only_single_file: If True only one file can be selected
+        '''
+        mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
+        fd = FileDialog(title=title, name=name, filters=filters, default_dir=default_dir,
+                        parent=window, add_all_files_filter=all_files, mode=mode,
+                        )
+        fd.setParent(None)
+        if fd.accepted:
+            return fd.get_files()
+        return None
+
+    def choose_save_file(window, name, title, filters=[], all_files=True, initial_path=None, initial_filename=None):
+        '''
+        Ask user to choose a file to save to. Can be a non-existent file.
+        :param filters: list of allowable extensions. Each element of the list
+                        must be a 2-tuple with first element a string describing
+                        the type of files to be filtered and second element a list
+                        of extensions.
+        :param all_files: If True add All files to filters.
+        :param initial_path: The initially selected path (does not need to exist). Cannot be used with initial_filename.
+        :param initial_filename: If specified, the initially selected path is this filename in the previously used directory. Cannot be used with initial_path.
+        '''
+        kwargs = dict(title=title, name=name, filters=filters,
+                        parent=window, add_all_files_filter=all_files, mode=QFileDialog.AnyFile)
+        if initial_path is not None:
+            kwargs['no_save_dir'] = True
+            kwargs['default_dir'] = initial_path
+        elif initial_filename is not None:
+            kwargs['combine_file_and_saved_dir'] = True
+            kwargs['default_dir'] = initial_filename
+        fd = FileDialog(**kwargs)
+        fd.setParent(None)
+        ans = None
+        if fd.accepted:
+            ans = fd.get_files()
+            if ans:
+                ans = ans[0]
+        return ans
+
+    def choose_images(window, name, title, select_only_single_file=True,
+                    formats=('png', 'gif', 'jpg', 'jpeg', 'svg')):
+        mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
+        fd = FileDialog(title=title, name=name,
+                        filters=[(_('Images'), list(formats))],
+                        parent=window, add_all_files_filter=False, mode=mode,
+                        )
+        fd.setParent(None)
+        if fd.accepted:
+            return fd.get_files()
+        return None
 
 def choose_osx_app(window, name, title, default_dir='/Applications'):
     fd = FileDialog(title=title, parent=window, name=name, mode=QFileDialog.ExistingFile,
@@ -696,68 +770,6 @@ def choose_osx_app(window, name, title, default_dir='/Applications'):
     if app:
         return app
 
-def choose_files(window, name, title,
-                 filters=[], all_files=True, select_only_single_file=False, default_dir=u'~'):
-    '''
-    Ask user to choose a bunch of files.
-    :param name: Unique dialog name used to store the opened directory
-    :param title: Title to show in dialogs titlebar
-    :param filters: list of allowable extensions. Each element of the list
-                    must be a 2-tuple with first element a string describing
-                    the type of files to be filtered and second element a list
-                    of extensions.
-    :param all_files: If True add All files to filters.
-    :param select_only_single_file: If True only one file can be selected
-    '''
-    mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
-    fd = FileDialog(title=title, name=name, filters=filters, default_dir=default_dir,
-                    parent=window, add_all_files_filter=all_files, mode=mode,
-                    )
-    fd.setParent(None)
-    if fd.accepted:
-        return fd.get_files()
-    return None
-
-def choose_save_file(window, name, title, filters=[], all_files=True, initial_path=None, initial_filename=None):
-    '''
-    Ask user to choose a file to save to. Can be a non-existent file.
-    :param filters: list of allowable extensions. Each element of the list
-                     must be a 2-tuple with first element a string describing
-                     the type of files to be filtered and second element a list
-                     of extensions.
-    :param all_files: If True add All files to filters.
-    :param initial_path: The initially selected path (does not need to exist). Cannot be used with initial_filename.
-    :param initial_filename: If specified, the initially selected path is this filename in the previously used directory. Cannot be used with initial_path.
-    '''
-    kwargs = dict(title=title, name=name, filters=filters,
-                    parent=window, add_all_files_filter=all_files, mode=QFileDialog.AnyFile)
-    if initial_path is not None:
-        kwargs['no_save_dir'] = True
-        kwargs['default_dir'] = initial_path
-    elif initial_filename is not None:
-        kwargs['combine_file_and_saved_dir'] = True
-        kwargs['default_dir'] = initial_filename
-    fd = FileDialog(**kwargs)
-    fd.setParent(None)
-    ans = None
-    if fd.accepted:
-        ans = fd.get_files()
-        if ans:
-            ans = ans[0]
-    return ans
-
-def choose_images(window, name, title, select_only_single_file=True,
-                  formats=('png', 'gif', 'jpg', 'jpeg', 'svg')):
-    mode = QFileDialog.ExistingFile if select_only_single_file else QFileDialog.ExistingFiles
-    fd = FileDialog(title=title, name=name,
-                    filters=[('Images', list(formats))],
-                    parent=window, add_all_files_filter=False, mode=mode,
-                    )
-    fd.setParent(None)
-    if fd.accepted:
-        return fd.get_files()
-    return None
-
 def pixmap_to_data(pixmap, format='JPEG', quality=90):
     '''
     Return the QPixmap pixmap as a string saved in the specified format.
@@ -776,16 +788,15 @@ def decouple(prefix):
 
 class ResizableDialog(QDialog):
 
+    # This class is present only for backwards compat with third party plugins
+    # that might use it. Do not use it in new code.
+
     def __init__(self, *args, **kwargs):
         QDialog.__init__(self, *args)
         self.setupUi(self)
         desktop = QCoreApplication.instance().desktop()
         geom = desktop.availableGeometry(self)
-        nh, nw = geom.height()-25, geom.width()-10
-        if nh < 0:
-            nh = max(800, self.height())
-        if nw < 0:
-            nw = max(600, self.height())
+        nh, nw = max(550, geom.height()-25), max(700, geom.width()-10)
         nh = min(self.height(), nh)
         nw = min(self.width(), nw)
         self.resize(nw, nh)
@@ -1036,12 +1047,12 @@ def sanitize_env_vars():
     is needed to prevent library conflicts when launching external utilities.'''
 
     if islinux and isfrozen:
-        env_vars = {'LD_LIBRARY_PATH':'/lib', 'QT_PLUGIN_PATH':'/lib/qt_plugins', 'MAGICK_CODER_MODULE_PATH':None, 'MAGICK_CODER_FILTER_PATH':None}
+        env_vars = {'LD_LIBRARY_PATH':'/lib', 'QT_PLUGIN_PATH':'/lib/qt_plugins'}
     elif iswindows:
-        env_vars = {k:None for k in 'MAGICK_HOME MAGICK_CONFIGURE_PATH MAGICK_CODER_MODULE_PATH MAGICK_FILTER_MODULE_PATH QT_PLUGIN_PATH'.split()}
+        env_vars = {k:None for k in 'QT_PLUGIN_PATH'.split()}
     elif isosx:
-        env_vars = {k:None for k in
-                    'FONTCONFIG_FILE FONTCONFIG_PATH MAGICK_CONFIGURE_PATH MAGICK_CODER_MODULE_PATH MAGICK_FILTER_MODULE_PATH QT_PLUGIN_PATH'.split()}
+        env_vars = {k:None for k in (
+                    'FONTCONFIG_FILE FONTCONFIG_PATH QT_PLUGIN_PATH SSL_CERT_FILE').split()}
     else:
         env_vars = {}
 
